ParallelInvokeSlot

Struct ParallelInvokeSlot 

#[repr(C, align(64))]
pub struct ParallelInvokeSlot { pub status: AtomicU32, pub _pad0: u32, pub job_id: AtomicU64, pub packet: InvokePacket, pub result: InvocationResult, }
One host<->guest invoke slot. Slots are addressed by lane index at parallel_slot_base + lane * PARALLEL_INVOKE_SLOT_BYTES.

Synchronization protocol:

  • host writes job_id and packet, then stores READY with release;
  • guest CASes READY -> RUNNING, runs the invoke, writes result, then stores DONE with release;
  • host reads DONE with acquire, copies result, then stores EMPTY.

Bench-only control commands, such as EVICT_JIT_READY, use the same RUNNING -> DONE -> EMPTY completion protocol after the host reserves all lanes.

Fields

status: AtomicU32_pad0: u32job_id: AtomicU64packet: InvokePacketresult: InvocationResult